
# q-expansion of newform 6275.2.a.e, downloaded from the LMFDB on 14 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 6275
weight = 2
poly_data = [256, 2240, 1920, -8800, -9400, 13752, 13680, -11921, -9216, 6186, 3178, -1867, -582, 317, 54, -28, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-4, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[27776, 183520, -55216, -779784, 54216, 1198330, -146661, -866052, 174414, 313888, -79979, -59424, 17157, 5638, -1752, -212, 69], 1216], [[17152, 171520, 340608, -267960, -1279884, -245024, 1586747, 495896, -968122, -247094, 314373, 54778, -55271, -5722, 4968, 230, -179], 1216], [[448, 4336, 4320, -13706, -16325, 14855, 18119, -7882, -9331, 2275, 2570, -363, -391, 30, 31, -1, -1], 16], [[19360, 195424, 174400, -579208, -668672, 562305, 757131, -253970, -403848, 60405, 115839, -7691, -18373, 482, 1518, -11, -51], 608], [[-23776, -190336, -170912, 587700, 694624, -619761, -783066, 323534, 401886, -91723, -109772, 14297, 16568, -1148, -1306, 37, 42], 608], [[-16672, -149088, -229168, 362868, 874658, -197467, -1047432, -22298, 598948, 42159, -182968, -12029, 30590, 1412, -2640, -61, 92], 608], [[-1184, -30992, -125672, 12012, 441435, 143716, -539429, -176682, 321823, 78608, -102092, -16544, 17575, 1676, -1551, -66, 55], 304], [[3424, 24816, 132396, 58112, -496127, -322886, 642219, 344458, -409343, -147646, 136930, 30574, -24529, -3068, 2231, 120, -81], 304], [[63040, 666880, 907248, -1879504, -3345112, 1609452, 3830305, -586448, -2071842, 92994, 601779, -3222, -96501, -670, 8052, 54, -273], 1216], [[48064, 519552, 1043968, -1024856, -3809188, -26942, 4578639, 762564, -2675294, -428616, 835349, 98824, -142215, -10522, 12452, 428, -439], 1216], [[-61824, -611552, -1129472, 1407544, 4154208, -543666, -4922425, -342348, 2801974, 273060, -853111, -68940, 142177, 7662, -12232, -320, 425], 1216], [[-56064, -485856, -398368, 1603204, 1579552, -1850923, -1714617, 1064194, 833640, -329651, -213597, 55745, 30039, -4842, -2194, 169, 65], 608], [[-67264, -722496, -1261376, 1745216, 4631952, -880308, -5465293, -183376, 3091250, 233070, -935823, -63482, 155249, 7286, -13308, -310, 461], 1216], [[107392, 967520, 1507920, -2302448, -5763440, 1066508, 6899717, 366384, -3955826, -365766, 1212007, 96466, -203129, -10934, 17564, 462, -613], 1216]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, -1, 0, 0, -1, 0], [1, 0, 0, 0, 0, -1, 1, 1, -1, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 1, 0], [1, 1, 0, 1, 1, -1, 0, 2, -1, 0, 0, 1, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 1, -1, 0, 0, 0, -1, 1, 0, 0, 1, 1, 0], [0, -1, 0, 0, 1, 0, 1, -1, 0, -1, 0, -1, 0, 0, 0, 0, -1], [1, -1, -1, -1, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 1], [2, -2, 1, 1, 0, 0, 2, -1, 0, -1, 0, -1, -1, 0, 0, 0, -1], [-3, 1, 0, 1, -1, 0, -1, -2, 1, 1, -1, 0, 0, -1, 2, -1, 0], [0, 0, 0, 0, 0, 0, -1, -1, -1, 0, 0, 1, 1, 0, 0, 0, 0], [-2, 0, -1, -2, -2, -1, 1, 1, 0, 1, 0, -1, 0, 3, -1, -3, 1], [1, 0, -1, -2, -2, 0, -2, 0, -1, 1, 0, 1, 2, 1, 0, 1, 1], [1, -1, 0, 1, 1, -2, 1, 2, -1, -1, 1, 0, 0, 1, -2, -1, 0], [-3, 1, -1, -1, 1, 1, -2, 2, 0, 0, -2, 0, 0, 0, 1, -1, 1], [4, 0, 1, -2, -2, -1, -1, 2, -1, 1, 1, 0, 0, 1, -1, -2, 1], [-1, 0, -1, 0, -1, 0, 1, 3, 0, 1, 1, 0, -2, 1, -1, -2, 1], [1, 1, 1, 3, 1, -1, 2, -1, -1, 0, -1, 1, 0, -2, 1, 2, -1], [3, -1, 4, 2, -1, -1, 2, -3, 0, -1, 0, -1, -1, -2, 1, 1, -2], [1, 1, -1, -1, 1, 1, 0, 1, 0, 0, 0, 0, -2, 0, -1, -1, 1], [-1, 0, -2, 0, 0, 1, -1, 2, -1, 1, -1, 2, 2, 1, -1, 0, 1], [1, 1, 0, -2, -1, 0, -1, 1, 0, -1, 0, 1, 0, 3, 0, 0, 0], [1, -2, 1, 0, 0, 2, 0, -1, 0, -1, 1, 0, 0, 1, 2, 0, -1], [-1, 1, -3, 0, 1, 0, -3, 2, 0, 2, -3, 1, 2, 1, 2, 0, 2], [-1, 1, 0, -4, -2, -1, 0, 2, 1, 0, 1, -1, 0, 4, -3, -3, 1], [3, 0, 1, 0, 0, -2, 2, -1, 0, -1, 1, -2, 0, 1, 0, 0, -1], [6, 3, 0, 1, -1, -1, 0, -1, 0, 1, -1, 0, 2, -1, 1, 1, 0], [-2, 0, -2, -4, -3, -2, 1, 2, 0, 2, 0, -2, 2, 4, -3, -4, 0], [-3, -2, -3, -2, -2, 0, 0, 0, 1, 1, -2, 1, 2, 1, 0, -1, 1], [4, 0, 5, 4, 1, -1, 0, -3, 0, 1, 0, 3, 0, -3, 2, 3, -1], [6, -3, 2, 3, 3, -1, 2, -3, -2, -3, -1, 0, 0, -3, 1, 3, -2], [0, -3, -2, -1, -1, -1, 6, -1, 2, -1, 1, -4, -2, 1, -1, -3, 0], [7, -4, 2, 1, 2, 1, 1, 2, -2, -4, 3, -1, -2, 2, -3, 1, -2], [2, -1, 1, 1, 1, 0, -1, -2, -2, 2, 1, 1, 2, -2, 0, 2, -1], [-2, 0, 0, -2, -2, -2, -2, 3, -1, 2, 1, 1, 2, 4, -2, -1, 0], [3, -1, -1, 3, 3, 1, 0, 2, 0, -2, 0, 4, -2, -2, 1, 1, 1], [-1, 0, -2, 0, 4, 3, -1, -1, -1, 0, 0, 0, 0, -2, -1, 2, -2], [-7, 4, -4, -4, -2, 1, -3, 3, 0, 3, -4, 1, 2, 1, 1, -1, 3], [-3, -4, 1, -4, -2, -1, 3, -3, 2, 0, 2, -5, 0, 0, -2, -3, -3], [4, 2, 1, 3, 3, 0, -2, 2, -1, 2, 1, 1, 0, -4, 0, 2, -2], [-3, -3, -3, -5, -3, 1, -2, 4, -2, 0, 0, 0, 2, 4, -1, -1, 3], [-3, 3, -1, 1, -1, -1, -2, -1, 1, 2, 1, 1, 0, 0, 1, 0, -1], [5, -3, 1, -5, -2, -3, 3, 1, -1, 0, 1, -3, 0, 4, -4, -2, -1], [-2, 3, 0, -3, -1, -1, 0, 2, 1, -1, -2, -1, 0, 3, -1, 0, 2], [5, 1, 3, -1, -1, -2, 1, 1, -1, -1, 0, 1, 0, 1, 0, -1, 0], [0, -2, 1, 0, 0, 1, 1, -2, -1, -1, -1, -4, 0, -1, -1, 0, -1], [2, 5, -4, -1, -1, 2, -3, 2, -1, 0, 1, 4, 2, 2, 3, 1, 0], [0, 1, 2, 5, -3, -1, 0, -3, 0, 3, 1, 0, 2, 1, 1, -1, -2], [-3, 0, 0, -4, -2, -2, 0, 3, 1, 1, 1, -4, 0, 3, -4, -3, 3], [-3, 0, 1, 2, 0, -2, 4, -1, -2, -1, 1, -2, -2, -1, -2, -2, -3], [1, -2, 3, 0, 0, -3, 1, 1, -2, 2, 2, -1, 0, 0, -4, -1, -1], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 2, -2, 0, -2, 1, 1, 0, 2, 0, -1, -1, -2, 0, -1, -3, 0], [4, 1, 5, 2, -2, -1, 2, -5, -1, -1, 4, -1, 0, 1, -1, 1, -2], [1, -3, 1, 3, 1, -1, 2, -3, 1, 0, 5, 1, 0, 0, -3, 0, -3], [-6, -3, -3, -5, -3, 3, -2, -6, 4, -1, 0, -2, 0, 1, 2, -1, 1], [-4, 3, 3, 5, 3, -2, 1, -2, 0, -2, -1, -1, 2, -2, -2, 4, -5], [1, -8, 2, 2, 2, -1, 3, -3, -1, -2, 2, -4, 0, 0, -3, 0, -2], [0, 0, 3, 4, 2, 1, -1, -5, 2, -1, 0, -1, -2, -3, 3, 1, -3], [2, 1, -1, 3, -1, 0, 5, -4, 2, 0, 1, -1, -2, -2, 4, -4, -1], [4, -3, 2, 3, 1, -1, 2, 0, -1, -3, 2, -1, -2, -1, -5, 0, 0], [-6, -3, 2, -2, -3, 0, 3, -6, 3, -1, 2, -3, 3, 2, 0, -3, -4], [1, 4, 0, -6, -4, -1, -3, -1, -1, 4, 0, 0, 4, 2, 1, 2, 2], [4, -2, 4, 1, -1, -1, 1, 0, 0, -5, 2, 1, -2, 1, -1, 0, -1], [1, -2, 2, -1, 2, -2, 2, -8, 2, 0, 1, -1, 1, -3, 0, 4, -2], [3, 4, 3, 8, 6, -2, 1, 0, -1, -1, -3, 1, -1, -7, 4, 4, 1], [1, -6, 0, 2, 2, -1, 5, -7, 1, -4, 2, -4, 0, -4, -3, 0, -2], [13, 1, 2, 3, 7, 2, 1, 6, -3, -3, -1, 2, -4, -1, 0, 3, 0], [-3, -3, -2, 5, 3, 2, 1, 0, -1, 1, -1, -2, -2, -1, 0, -3, -2], [-5, 2, -5, -2, 2, -1, -5, 4, 1, 2, -5, 2, 4, 0, 0, 2, 1], [-1, 2, 3, -2, -2, 0, 0, -1, 0, -3, -1, 0, -2, 1, -2, 2, -1], [-9, -3, -3, -4, 3, 2, -3, 3, -3, 0, 0, 2, 2, 1, -2, 1, 0], [9, -3, 5, 5, 3, 1, 2, -4, 0, -4, 0, -2, 0, -4, -1, 5, -3], [0, 0, 0, 0, -2, 2, 0, -1, 1, 2, 1, -1, 0, 2, -2, -3, -2], [3, -3, -3, -3, 1, -1, 4, 6, -2, -4, 2, -4, -4, 4, -5, -3, -1], [2, -5, -1, 1, -1, 2, -1, 0, 2, 0, 1, -1, -2, -2, 4, 0, -1], [-4, 2, -5, -4, -2, 1, -1, 5, 0, 1, 4, 1, 0, 5, -3, -5, 1], [2, 1, 3, 5, -1, -2, 1, 2, -2, 2, 1, -3, -2, 2, -4, -4, -1], [-4, -5, 1, -5, -1, 4, 3, -2, 0, -4, 3, -5, 0, 2, -4, 0, -1], [14, -5, 5, 5, 1, 2, 3, -8, 2, -6, 1, -1, -2, -4, 2, 2, -1], [6, -2, -1, -5, 0, 1, 3, 8, -3, -3, 1, 0, -2, 1, -3, 2, 3], [5, -2, 4, 4, 2, -3, 5, 1, -3, -4, 4, -4, -4, 2, -5, 2, -4], [0, -3, -1, 3, 3, 0, 3, 5, -3, -2, 4, 0, -4, 2, -2, -3, -3], [-1, -2, 0, -2, -2, 1, 5, -8, 3, -1, 3, 0, -2, -1, -1, 0, -3], [6, 3, -1, 8, 2, 1, -2, 3, -1, -1, 0, 7, -2, -1, 5, 3, 2], [-3, 6, -4, -4, 4, 5, -7, 6, 0, -4, -7, 3, -2, 0, 3, 1, 6], [1, 5, 2, -5, -5, -2, -3, 4, -3, 1, -1, 0, 6, 7, -2, 1, -2], [-2, -1, -3, 5, 3, 0, -1, 3, -1, 2, -2, 2, 2, 0, 0, 1, 1], [2, -2, 1, 2, 2, 1, 1, -3, 0, -3, -2, -1, 0, -5, -1, 1, -1], [-3, 2, -1, -6, 0, 0, -6, 4, -1, 1, -6, -3, 4, 3, -6, 3, 1], [4, 4, 2, 0, 2, 0, -2, 1, 1, 2, -1, 1, -2, -2, 2, -1, 2], [4, -3, 1, 7, 3, 2, 1, 1, -2, 0, -1, 3, -4, -4, 0, 0, -1], [-8, 1, -2, 5, 3, 5, -6, -2, 1, 1, -2, 5, -2, -7, 5, 2, 2], [-1, 3, -2, -7, -3, -6, -1, 7, -1, 1, -1, 2, 4, 5, -4, -1, 4], [1, -4, 4, 0, 0, 2, -2, 0, -2, -3, 2, 1, 4, 1, -2, 4, -1], [5, 1, 3, 1, 1, -5, -2, 4, -4, 0, -4, 0, 2, 2, 1, -1, 1], [-3, -1, -4, -12, -5, 1, -2, 5, 2, -3, -3, -6, 2, 10, -3, -3, 3], [9, -2, 0, -1, 0, 2, 2, -7, 3, -2, 3, -1, -2, 3, 0, -1, -3], [4, -8, 4, -3, 0, -1, 7, -1, 1, -4, 5, -1, -1, -1, -1, 0, -2], [5, 1, 0, -1, -1, 0, -5, 2, -3, 3, -5, 0, 4, -1, 0, 5, 2], [11, 0, 10, 6, -2, -3, -1, -9, -1, 2, 0, -2, 2, -6, 1, 4, -6], [8, -1, 0, 5, 5, 3, -2, 1, -1, 0, -5, -1, -2, -6, 1, 2, -1], [-2, 1, -3, 3, 5, 0, 1, 5, 0, -3, 0, 3, -4, 3, 2, 0, 2], [8, -5, 4, 1, -3, -1, 2, -1, -3, 4, 5, 1, -2, 2, -3, 0, -1], [-4, -6, 7, 6, 6, 1, 1, 1, -7, 1, 1, 0, -2, -7, -3, 6, -1], [4, 1, 1, -6, -7, -1, -4, 3, 1, 0, 2, 0, 1, 9, 1, -4, 3], [5, 3, 2, 1, -3, -4, -1, 0, -3, 5, 5, 4, 0, 3, -2, 3, -2], [3, 7, 1, -7, -7, -5, -2, 3, 1, 4, 3, -1, 2, 2, -1, -2, 1], [-6, 0, -3, -8, 0, 9, -5, -2, -2, -2, 3, 1, 2, -2, -1, 1, 0], [2, 1, 1, 5, 1, 2, 3, -4, 2, -6, 1, 1, -4, -2, 2, -2, -3], [0, 5, -5, -14, -5, 0, -9, 9, -1, 4, -4, 4, 4, 8, 0, 1, 7], [12, -3, 4, 7, 10, 1, 3, 3, -6, -5, -3, 2, -4, -5, -2, 7, 0], [9, -1, 3, 1, 3, -3, 4, 6, -4, -2, -2, -2, -4, -2, -3, 1, -1], [1, -1, -1, -1, 3, 5, -6, 3, -5, 0, -1, 7, 4, -2, -1, 6, 3], [4, 0, 6, 0, 0, 4, 4, -12, -2, -6, 2, -2, -4, -4, 2, 0, -4], [0, 6, -4, -4, -4, 2, -6, 3, 1, 4, -3, 5, 4, 2, 4, 1, 2], [0, -3, 0, -1, -5, 1, 0, -4, 3, 3, 2, -1, 0, 1, -1, -2, 4], [-4, 4, -6, -8, -8, 2, -2, -3, 5, 0, -5, -1, 2, 6, 4, -1, 6], [-1, -1, -2, -3, 7, 4, -5, 3, -2, -3, -6, 3, 2, -1, 2, 4, 4], [8, -1, 4, 5, 3, -1, 4, -8, 3, -1, 0, 1, 0, -5, -1, 4, -6], [-4, 2, -8, -5, 6, 3, -3, 5, -1, -2, -1, 3, 3, -3, -1, 2, 0], [5, -4, 3, -8, 0, 6, -2, 0, 0, -1, -1, -4, 0, -3, 0, 2, 5], [4, -8, -1, -4, 2, 0, 2, 7, -4, -6, -1, -3, 0, 8, -4, 0, -2], [10, -2, 0, 0, 2, 2, -2, -2, 2, 0, 4, 2, 0, -2, 0, -4, 0], [-1, 0, 3, 4, -8, -4, -1, -3, 0, 5, 2, -2, 5, 5, -4, -1, -1], [22, 1, 2, 4, 4, 0, -7, 10, -5, 0, 4, 10, -2, -4, -2, 6, 3], [4, 7, -1, -3, -3, -3, -4, 11, 1, 3, -3, 1, 0, 7, 0, 0, 5], [1, 0, 3, 0, -2, 0, 0, -1, 2, -1, 1, -6, 0, 3, 0, 0, 1], [-4, -1, -8, -8, -4, 0, 3, 2, 3, 2, 0, -4, 2, 2, 2, -8, 3], [11, -5, 8, 2, 3, 2, 1, 2, -3, -1, 3, 0, 0, -1, -4, 5, -2], [-3, 0, -9, 1, 5, 1, 1, 8, 1, 0, 0, 2, -4, 4, -3, -9, 2], [-8, -1, -2, -8, -1, 6, -9, -2, 3, 1, -8, 1, 3, -4, 6, 7, 6], [-11, 3, -2, -1, -3, 2, -3, 0, 3, 1, -1, 2, 4, 7, -2, 1, 2], [-4, 1, 3, -5, -5, 5, -6, -2, 4, -1, -6, -1, 6, 3, 3, 3, 2], [3, 7, -1, 6, 5, -4, -9, 11, -7, 6, -7, 5, 5, 1, -2, 3, 5], [-10, 11, -9, 3, -1, 4, -7, 3, 1, 6, -6, 6, 0, 0, 6, -1, 9], [6, 3, -3, 1, 1, -6, -1, 12, -6, 6, 5, 5, 0, 4, -6, -4, 5], [-12, 8, -6, 2, 0, 2, -2, 4, 2, 2, -2, 6, -2, -2, 6, 0, 0], [3, -3, 2, 10, 2, 5, 8, -11, 6, -6, 0, -8, -4, -4, 1, 0, -5], [5, 9, 2, 3, 2, -2, 2, 2, 1, -1, 1, 2, -2, 1, -1, -1, -2], [11, -1, 0, -3, 1, -2, -3, 5, 0, -1, -4, 5, 4, -1, -4, 8, 2], [-20, 0, 5, 0, -2, -5, 3, 2, -1, 1, -1, -6, 2, 1, -5, -2, -3], [14, -3, 1, 1, 1, -4, 3, -5, 1, -4, -2, -4, 0, 0, -2, -1, -3], [6, -7, 8, 3, 3, -5, -4, -6, -4, 1, -3, 0, 6, -5, -1, 9, -4], [-15, 4, -8, -4, -11, 5, -6, -3, 5, 4, -4, 0, 4, 4, 6, -4, 4], [8, -2, 3, 6, -2, 3, -1, -1, -2, 1, -4, 3, 2, -1, 3, 1, 1], [-4, 1, 2, 7, 5, 4, 5, -3, 0, -4, 6, -3, -6, 0, 3, 2, -4], [0, 3, 1, 5, -3, 0, -8, -3, 1, 4, -5, 8, 5, -6, 8, 8, 1], [-9, 2, 0, 3, 3, 8, -2, -2, 6, -5, 1, 0, -4, 1, 8, 3, 1], [3, -8, 5, -2, 0, 0, 8, 2, -1, -1, 8, -7, -10, 1, -2, -11, 1], [-3, -2, -6, -14, -10, -1, -1, 1, 3, 4, -2, -6, 4, 6, 1, -6, 4], [1, -4, -3, -2, 2, 0, 4, -4, 1, -5, -2, -5, 0, 1, -2, 1, -3], [2, -6, 6, 2, 2, 0, 2, -1, 0, -3, 7, -2, -4, -1, -4, 0, -7], [16, 5, 1, 9, 1, -12, 3, 5, -3, 6, -2, 0, 2, 0, -2, -1, -1], [5, 3, 2, 1, 3, 0, 1, -6, -1, -1, -1, 4, 2, -1, 8, 9, 0], [-10, -4, 2, 4, -6, -4, 4, 0, -2, 2, 0, 2, 2, 6, -2, 0, 0], [11, -1, 6, -1, 3, -4, -1, 11, -6, 3, 4, 7, 0, 1, -8, 4, -2], [-6, 9, -4, -1, -5, 1, -6, 6, -1, 3, 2, 9, 4, 5, 3, 0, 6], [3, -2, 4, 6, 8, 1, -2, 2, -4, 0, 2, -1, -5, -4, 1, 4, -4], [15, -3, 6, 3, 1, -4, 3, -6, -1, -5, 1, -2, 0, -3, 2, 1, -6], [-9, 7, -6, 4, 5, -1, -6, 2, 1, 5, -4, 5, 2, -4, 1, 4, 3], [-9, 5, -3, -9, -7, 8, -3, 2, 2, 3, -1, 0, 4, 3, 0, -6, 4], [21, -1, 2, 7, -1, 0, 7, -2, -1, -3, 5, -2, -4, 1, 2, -1, -2], [4, 3, -1, 13, 15, -2, 5, 10, -4, -8, -3, 5, -4, -4, 0, 6, -1], [14, -7, 3, 5, -1, -4, 9, -1, -3, -2, 6, 0, -4, -6, -4, -1, -1], [-1, -8, 5, 10, 4, -2, 6, -7, -2, -3, -1, 2, 2, -5, 2, 2, -7], [-5, 5, 1, -11, -5, -4, 1, 4, 2, 1, 1, -7, 2, 9, -7, -8, 1], [6, 9, 2, 7, 7, 7, -8, 4, 3, 1, -6, 5, -2, -7, 5, 6, 4], [-9, 0, -4, 8, 0, -4, 0, 8, 2, 7, -4, 1, 0, -1, -2, -6, 1], [4, -3, -9, -9, -1, 4, -5, 10, 1, 0, -2, 2, -4, 6, 0, -1, 7], [2, 2, 9, 2, -1, -5, 6, -5, 0, -5, 4, -3, -4, -1, -2, -5, -9], [0, 0, -8, -4, -4, 2, -8, 4, -2, 4, -6, 0, 6, 4, 2, -2, 4], [-1, -4, 9, -3, -4, -3, -1, -9, 2, 1, -4, 1, 6, -4, 3, 5, -4], [-6, 8, -6, 3, 0, 3, 3, 1, 3, -2, 3, 3, -3, 3, 3, -6, 2], [3, -5, -4, 1, -5, 0, 1, -1, -2, 9, 0, -3, 2, -1, -4, -6, 2], [20, -1, 5, 9, 7, -2, -1, -1, -1, -2, 0, 8, 2, -10, 2, 9, 1], [8, 7, 0, 1, 5, -7, 2, 10, -1, 1, -6, -3, -6, 1, -3, -4, 0], [3, 2, -1, -5, -10, -3, -3, -5, 8, 1, 2, -1, 4, 6, -1, -1, 4], [2, 4, 0, -4, -6, -4, -2, 13, 0, 8, 4, 0, 0, 4, -8, -4, 4], [9, 4, 2, 8, 6, -3, 3, 3, -5, -6, 6, 2, -4, -2, -1, 2, -2], [3, 3, 4, 5, 4, -2, 4, 1, 0, -7, -2, 5, -6, -7, 3, 4, -2], [-12, -9, -2, 0, -1, 4, -5, -4, 1, -1, 1, 4, 2, -4, 2, -1, 1], [6, -1, -2, 5, -3, 3, 0, 6, -1, 1, 0, 3, -6, -1, 1, -4, 4], [-6, -3, -6, -1, 2, 7, -7, 8, -5, 5, -2, 5, 0, -5, -2, 0, 6], [-22, -6, -5, -2, 2, -5, 7, 4, -2, 0, 5, -7, 2, 4, -7, -9, 0], [2, -6, 3, -1, 0, 4, 4, 3, 2, -5, 7, -2, -8, 2, -2, -2, 2], [0, -1, -4, 8, 1, -5, -2, 4, 1, 5, -6, 1, 6, -1, 1, 0, 6], [21, 1, 3, 3, 9, 1, 8, 5, -3, -6, 1, -5, -6, 0, -3, -6, -5], [-3, -9, 4, 1, -7, 2, 7, -16, 4, 1, 2, -3, 4, -1, 2, -2, -4], [-11, 3, -8, -9, -9, 0, 1, -6, 7, 7, 3, -4, 0, 5, 2, -15, 2], [1, 1, -6, -9, -5, -6, -5, 19, -6, 5, 0, 1, 4, 11, -8, -2, 6], [-17, 14, -2, -2, -2, 1, -13, -2, 4, 4, -9, 3, 2, -4, 5, 3, 6], [-7, -4, -3, 6, 4, 8, 4, 4, 1, -5, -2, -3, -4, 1, 4, -5, -1], [-15, 5, -3, -1, 7, 9, -5, -1, 5, -2, 2, 3, -7, -2, 7, -1, 3], [3, -11, 4, 4, 3, -1, 10, -4, -7, -5, 5, -8, -1, -4, -9, 4, -4], [13, 0, 3, 11, 12, 1, -7, 7, -6, 1, -5, 8, 1, -10, 5, 9, -1], [2, 2, 2, 0, 0, 0, -6, 1, 5, 2, -7, -1, 2, -10, 2, -1, 6], [9, -8, 13, 4, 0, -5, 5, -9, 2, -2, 4, -2, -2, 0, -1, -1, -8], [15, -6, 13, 2, 0, -8, 8, 1, 0, -1, 7, 0, -4, 1, -6, -4, -5], [6, 2, -2, 6, 5, 2, 13, -3, -1, -4, 7, -1, -10, -4, 1, -3, -4], [3, -2, 6, 6, 10, -3, 6, 4, -4, 0, 8, 3, -3, -2, -5, 0, -8], [0, 7, -1, -8, -4, 1, -4, -4, 4, 1, -3, -6, 6, -1, -1, 2, -4], [-9, -1, -5, 2, -1, 0, 1, -8, 0, 0, 0, -2, 5, -3, 4, 0, 1], [5, 4, 7, 21, 4, -5, 7, -13, -2, -7, 7, 4, -5, -8, 7, 3, -9], [2, -6, 1, -10, -6, 1, 7, -6, -1, 5, 5, -6, -4, -1, 1, -2, -3], [15, -15, 8, 7, 7, 1, 10, -6, -7, -10, 2, 0, -2, -6, -3, 6, -5], [8, -2, 0, 8, 6, 2, -2, -4, 2, -4, -2, 10, 4, -6, 8, 12, 0], [-6, 7, -7, -7, -5, 0, -10, 4, 4, 2, 2, 5, 1, 6, 2, -3, 7], [4, 1, 3, -5, -5, 8, -9, -1, 5, -2, -6, 2, 0, -4, 2, 9, 9], [-12, -5, -1, -5, -5, 2, 1, 2, 0, -2, -5, -5, 2, 2, 2, 2, 1], [9, 6, -6, -2, -6, -4, -2, 3, -1, -1, 5, 3, 6, 11, -1, -1, -2], [-12, -1, -9, -10, -9, -1, -8, 9, 1, 6, 3, -1, 2, 13, -1, -12, 4], [-5, 5, -4, -17, -5, -5, -8, 13, -2, 2, -5, 6, 4, 6, 0, 5, 10], [9, -4, 6, -4, 2, -1, -5, 3, -8, -1, 6, 3, -6, 1, -1, -3, -1], [-14, -5, -1, -7, -5, 6, -7, 1, -1, 2, 2, -6, 6, 4, -4, -3, 1], [-1, 4, -1, 4, -5, -4, 5, 7, 2, 3, 3, 4, -6, 3, 1, -4, 7], [-17, 6, -4, -3, -7, -8, 4, 5, 5, 3, 2, -3, -2, 13, -2, -14, 3], [-1, -8, -5, 5, 4, 9, -3, -1, 2, 1, -7, 6, 3, -4, 1, 9, 3], [21, -5, -1, -11, -3, -3, 4, 2, 4, 0, 4, -4, -2, 4, -5, -7, -5], [-13, -4, -3, -7, -6, 11, -7, -2, 5, -3, 0, -3, -1, 6, 5, -8, 1], [2, -5, -1, -7, -2, 0, 0, 2, 0, -4, 5, -7, -2, 2, -1, -6, 3], [14, -12, 1, 4, 2, -1, 13, 0, -1, -3, 5, -8, -10, -5, -5, -8, -5], [10, 5, 8, 1, 1, -5, -2, -2, -5, -3, 2, 1, 2, -1, -5, 8, -10], [21, -8, 3, 4, 4, 2, -9, -3, -4, -3, -6, 0, 11, -3, 2, 7, -5], [-19, -1, -3, -9, -3, 7, -10, 3, 7, 4, -3, -1, 2, 6, 3, -8, 5], [3, -11, 4, -1, -1, 2, 11, -1, -2, -1, 4, -7, -4, 3, -6, -6, -2], [13, -8, 4, -8, -11, -3, 2, -1, 1, 2, 4, -2, 0, 14, 0, -12, -6], [3, 0, -3, 1, 10, 3, 9, -2, -7, -3, 4, -7, -5, -6, -3, 0, 1], [-13, 9, 0, -5, -1, 2, -3, 2, 0, 3, -10, -5, 0, -3, 2, -2, 8], [4, 4, 13, 3, -2, -1, 7, -4, -3, -7, 1, -4, -6, 1, -1, 4, -7], [-5, -10, 2, -6, -4, 3, -5, -11, 7, 4, -6, -8, 2, -6, 7, 2, 4], [3, -8, 3, -8, -2, -4, 10, 2, -1, -3, 2, -13, -4, 9, -8, -11, -1], [-9, -7, -2, -7, -3, -2, 1, 6, 3, 3, 5, -2, -2, 15, -8, -15, -2], [7, -4, 8, 4, 9, 7, 0, 3, -7, -10, 2, 8, -4, -6, -2, 10, -2], [-13, -2, -7, -4, -8, 6, -14, -13, 4, 11, -7, 0, 16, -1, 6, 4, 3], [-7, 3, -2, -7, -13, -6, 15, -11, 2, 1, 14, -11, -2, 5, -4, -18, 0], [9, -4, 6, 10, 12, -1, 1, 0, -6, -8, 1, 5, -6, -6, -1, 3, -4], [-9, 13, -2, 3, -1, -4, 0, -5, 6, 5, -7, 3, 3, -1, 8, -3, -2], [-12, 13, -4, -10, -8, -4, -5, 5, -4, 6, -3, 1, 2, 8, 0, -1, 5], [2, -18, 9, 10, 4, -5, 12, -18, 1, -1, 8, -14, -5, -5, -5, -7, -15], [18, -7, 0, -11, -9, -7, 10, -5, 4, -1, 9, -10, 2, 7, -11, -3, -4], [17, 1, 16, 7, -3, 0, 3, -11, 4, 1, 2, -9, -4, -5, 2, 4, -6], [-12, 5, -9, -5, -3, 2, -3, 23, -3, 2, 0, 4, -6, 6, -10, -5, 9], [-4, -6, 7, -2, 2, -3, 1, 2, -3, -3, 3, -4, 4, 1, -15, 2, -5], [12, -1, -4, 3, 3, 1, 4, 5, -4, -9, -3, 0, -6, -1, -7, 1, 0], [-10, 5, -10, -1, 3, -5, 0, 15, -7, 0, 3, 3, 2, 10, -7, 0, -3], [-5, -1, -4, -7, -5, 5, -14, 1, -2, 6, -1, 9, 2, 4, 7, -3, 5], [-16, 3, -12, 7, 11, -3, 4, 13, -4, 5, -3, 0, -4, -1, -3, -5, 4], [-7, -7, 3, 3, 9, 1, -4, 2, -1, -6, -5, 1, 2, -4, 5, 12, -1], [6, -3, 4, -5, 1, -1, 0, -2, 1, -1, -2, -1, -6, -5, 3, 0, 2], [3, -3, 4, 15, 15, 2, 9, -7, 3, -7, -3, 0, -4, -15, 8, 15, -10], [-10, 3, -1, 1, -3, 1, 0, 0, 4, 5, -2, 5, -2, -3, 3, -5, 2], [17, 7, 8, -1, 3, 0, -3, 2, -3, -5, -1, 6, -6, 1, -8, 5, 2], [-3, -4, 3, 9, 8, 2, 6, 6, -3, -7, 4, -1, -8, -3, -2, 1, -5], [11, 9, -7, -9, 1, -3, -8, 22, -5, 7, 4, 5, 2, 11, -11, 0, 6], [7, -14, 1, 1, 8, -1, 9, 0, -3, -7, 1, -6, -2, 0, -9, -8, -4], [-6, 6, -7, 6, -2, -11, 12, 0, 3, 5, 6, 2, -1, 7, -1, -13, -1], [10, 0, 2, 2, -2, -2, 2, 1, -7, -4, 5, 5, -4, 4, 4, 3, 0], [7, -14, 3, 18, 12, -2, 2, 5, -10, -3, 3, 2, -4, -1, 0, 2, -7], [6, -3, -2, 4, 12, 8, 1, 6, -1, -12, -4, 2, -10, -4, 2, 2, 3], [-8, 8, -6, 8, 6, -4, -12, 8, 0, 0, -16, 6, 4, -6, 4, 10, 8], [5, 6, -14, 2, 0, 5, -7, 19, -7, 6, 4, 10, 0, 6, 1, 0, 6], [-14, 1, -11, -11, -13, 0, 1, 2, 0, 4, -3, -1, 2, 6, -6, -4, 3], [-17, -7, 0, -3, -3, 12, 7, -13, 8, -7, 6, -11, -2, 3, 4, -6, 0], [13, -9, 6, 3, 5, 0, 11, 5, -4, 1, 10, -5, -4, -5, -2, -6, -8], [-5, 13, -4, -1, -7, 4, -11, -16, 7, 3, -5, 4, 6, -3, 12, 1, -2], [0, 4, 4, 0, 8, 0, 1, 0, 4, 0, 5, 4, -5, 0, -4, -1, -8], [-14, -17, 5, 1, 1, 4, 9, -21, 7, -8, 2, -10, 4, -2, 0, 1, -11], [6, 11, -6, -21, -9, -3, -4, 10, -1, 5, -4, -1, 8, 13, -3, 2, 8], [-2, -9, 3, 8, 5, 0, 9, -13, 1, -2, 2, 0, -4, -12, 4, 3, -1], [-10, 11, -14, -3, 1, 5, -12, 12, -1, 3, -6, 1, 2, 1, 1, -2, 10], [-8, -11, 1, 5, 5, -4, 7, -6, -2, 0, -3, -9, 6, 0, -4, -4, -7], [5, -1, 11, 10, -1, -6, -7, 2, 0, 6, 1, -3, 6, -3, 0, 6, -4], [23, -6, 6, -2, -6, -1, 3, 0, -2, -4, 5, -5, -4, 8, 1, -1, 0], [-15, 1, -10, 1, -3, 12, -13, -8, 7, 1, -7, 4, 2, 3, 10, -1, 4], [19, 5, -5, 3, -3, 3, 6, 3, 1, 2, -1, 1, -8, 2, 5, -12, -1], [9, 12, 5, 2, 0, 2, -4, 4, -5, 3, 4, 9, -2, -7, 6, 7, 3], [-2, 9, 2, 7, -9, -1, 0, -5, 4, -5, 1, 0, -2, 1, 1, 1, -2], [0, 0, 6, -16, -16, -7, -5, 1, -7, 5, 4, -1, 6, 15, -7, -2, 5], [2, -2, 0, 9, 10, 4, 2, -8, -6, -10, 2, 0, 0, -10, 0, 10, -12], [7, 5, 18, -1, -7, -6, 9, -11, -2, 3, 8, -5, 4, -7, 2, 6, -8], [0, 7, -10, -7, -5, -1, -8, 6, 1, 5, -12, 3, 8, 5, 7, 0, 6], [-19, -4, -8, -15, 0, 10, -8, 12, 2, -4, -5, -3, 1, 5, 0, -4, 4], [4, 2, 10, -1, 4, -3, -1, -2, 4, 0, -7, -9, -6, -3, 1, -1, -1], [-19, 14, -8, 6, 2, 1, -7, -5, 5, 4, -8, 10, 8, -4, 7, 10, 6], [5, -10, 11, 4, 0, -4, 4, -4, -3, 3, 0, -3, 0, -9, -4, -5, -5], [4, 1, 1, 15, 13, 9, -4, -11, -3, -3, -3, 4, -2, -17, 11, 10, -4], [-1, 6, 5, -2, 4, -4, 0, 2, 3, 3, -4, -7, 0, -5, 0, 3, -1], [9, -2, 3, -2, 6, 5, -11, 1, -8, -6, -6, 8, 6, -4, 3, 19, -2], [-12, 5, 3, 5, 7, -6, 3, 0, 0, -2, -1, 1, 6, -2, -8, 10, -5], [-21, 0, -2, -4, -2, -3, -3, 1, -2, 4, 7, 3, 2, 8, -3, -7, 2], [4, 2, -8, -18, -2, 2, 0, 2, 3, 4, 9, -3, 4, 10, -12, -1, -2], [-15, 4, -10, 0, -4, 3, -19, 12, 0, 14, -9, 9, 14, 2, -3, 9, 12], [-1, -2, 7, -6, -8, 0, 8, -6, 0, -2, 6, -8, -4, 10, 2, -8, -8], [-1, -3, -4, 3, 7, -1, -4, 12, -1, 0, 6, 10, -2, 0, -5, 6, 1], [-5, -14, -5, 8, 4, 8, -6, -12, 5, -3, -2, -1, 2, -1, 8, 5, -5], [-20, 5, -10, -4, -1, 2, -7, -3, 10, 7, -2, -3, 4, 2, 6, -12, -1], [15, 6, 2, -2, -4, 3, -5, -5, 7, 6, 0, 2, 0, -4, 7, 0, 2], [-24, 0, -9, 6, -2, 3, -7, -1, 2, 5, -8, 3, 4, -5, 7, 1, 9], [20, -2, -3, 1, 12, 6, -10, 13, -12, -3, -1, 8, -6, -8, 4, 10, 4], [7, -10, -1, 2, 4, 8, -8, 7, -4, -7, 3, 6, 2, -3, 4, 2, 3], [17, -4, 9, 8, 6, -6, 10, -12, -7, 3, 6, -1, 2, -5, -4, 5, -9], [-6, 14, -9, 6, -2, -1, -2, 5, 2, 7, 3, 5, -5, 1, 5, -8, 5], [-20, 9, -11, 1, -11, 7, 0, -4, 10, 1, -6, -4, 4, 5, 10, -11, 5], [18, -3, 18, 13, -5, 3, 10, -13, 0, 1, 7, -10, -4, -3, -1, 3, -12], [-9, -10, 0, -16, -4, -2, 4, 6, 4, 3, 14, -12, -6, 7, -11, -16, -2], [-7, -4, -1, 4, -3, -4, 15, -8, 5, -5, 10, -1, -2, 1, -3, -7, -5], [6, -12, 9, 10, 6, -4, 24, -6, -1, -10, 14, -5, -6, -6, -7, -1, -17], [4, -12, -4, -2, 2, 4, -2, 3, -7, 8, 3, -5, -2, -6, -8, -7, -2], [-4, -7, -8, 1, 3, -15, 16, 12, -7, 3, 2, -1, 0, 1, -9, -6, -2], [-1, -12, 0, 4, 18, 7, -1, 9, -6, -14, 7, 5, -6, -2, -9, 7, -4], [13, -4, 0, 1, 3, -4, -12, 12, -2, 1, -11, 6, 10, -3, 0, 3, 7], [-29, 4, -6, -5, -12, 0, -6, 4, 4, 2, -1, -1, -1, 13, 2, -8, 2], [4, -2, 12, 13, 2, -7, 7, 5, -5, -2, -1, -1, -3, -5, -7, 0, -4], [-12, 7, -2, 1, -3, -3, 3, -6, 7, -1, -1, -3, -5, -1, 11, 5, 4], [-2, -1, 8, 2, -3, -3, 12, -8, -5, 1, 10, -11, -2, 1, -9, -4, -6], [0, 7, -1, 0, -11, 2, -1, -15, 9, 6, 4, -6, 4, 10, 2, -11, -1], [6, -3, -3, 5, 1, 3, -4, 0, 6, -5, -6, 4, 4, -9, 4, 1, 1], [-6, -1, -7, -15, -5, -4, -5, 20, -9, 0, -2, 2, 8, 18, -12, 1, 9], [17, 14, 3, 16, 8, 0, -10, 0, 1, 7, -6, 15, -2, -11, 8, 13, 7], [18, -6, 19, 8, 4, -1, 13, -18, 1, -13, 5, -6, -6, -11, -1, 0, -13], [16, 1, 2, 11, 9, -4, 9, -10, -5, -2, -5, 1, -4, -14, 8, 13, 1], [5, 8, -8, 10, 4, 1, -3, 7, -3, -4, -2, 2, -6, -6, 1, 2, 2], [-15, 5, -11, -21, -19, -5, -6, 12, 5, 12, 1, 1, 2, 18, 3, -20, 13], [-19, 3, 8, 7, 9, 0, 3, -11, 2, -9, -2, -3, -8, -11, 6, 2, -6], [20, -7, -3, -1, 0, -6, 4, -2, -6, 2, 7, -3, 6, 4, -5, -6, -1], [11, -2, 2, 0, 8, 5, -3, -9, 1, -8, 2, 6, 6, -8, -1, 10, 0], [-10, 16, -1, 0, -2, -1, 8, -7, 4, 7, -7, 1, -3, -9, 11, -6, 7], [11, -6, -1, 10, 6, -10, 10, 13, -6, -1, 9, -6, -6, 5, -10, -10, 3], [-1, 11, -7, 5, 13, 9, -20, 6, -4, -2, -12, 8, 0, -4, 9, 9, 5], [-11, 0, -4, 12, 4, -1, -5, 9, -11, -2, 0, 4, 2, 6, 5, 6, 8], [15, -2, -4, -4, -4, 1, -5, 4, -4, 6, 1, -3, 4, 6, 1, -1, 0], [-11, -1, 6, 13, -8, -2, 4, -19, 12, 1, 4, -5, -2, -3, 13, -4, -6], [-12, -10, -15, -16, -4, 9, -7, 4, 1, 3, -1, 4, 8, 5, 3, -6, 9], [-7, 12, -8, -4, -8, -1, 1, 5, -1, 12, -4, -4, 0, 2, -5, -4, 2], [-6, -19, 4, -13, -5, 1, -2, 12, -3, -3, 2, 1, 6, 11, -3, 4, 4], [-3, 1, 4, 7, 8, 6, 8, -19, 2, -5, 12, 5, -2, -9, 13, 6, -14], [-18, -3, 1, -5, 1, 0, -7, -7, 8, 1, -4, -9, 0, 7, 2, -4, -2], [6, -11, 8, 3, 3, -5, 14, -4, -1, -13, -4, -13, -4, 5, -9, 2, -6], [11, -8, -6, -8, -10, -6, 12, 3, -1, 3, 9, -10, -4, 13, -8, -21, -7], [2, -1, -1, -15, -7, -6, -13, 15, -3, 0, -4, 10, 4, 6, -4, 5, 11], [-17, 5, -10, -6, -7, 6, -13, 6, -3, 3, -7, 6, 16, 11, 8, -3, 0], [-3, -2, 1, -4, -8, -3, -3, 9, 0, 2, 2, 1, 0, 4, 2, -3, 1], [-5, -5, 9, -7, -5, -6, 5, 0, -6, 5, 5, -8, 0, 5, -2, -4, -4], [18, 12, -1, 14, 2, -13, 17, 0, -5, 3, 9, 6, -2, -3, -5, 0, -7], [4, 8, -4, 9, 8, -4, 8, 10, -2, -4, 2, 6, 0, 4, 0, 6, 0], [9, 7, -13, 0, -6, 0, 17, 5, 5, 1, 3, -4, -6, 7, 0, -14, 4], [-1, 4, 2, -10, -8, 5, -13, 1, -1, 0, -2, -4, 10, 8, -5, -4, 0], [1, -5, -7, -3, 7, 7, 4, -2, 7, -9, 0, -3, -2, -5, -5, 2, -4], [7, 0, -1, 1, -7, -7, -13, 15, -4, 2, -1, 11, 6, 6, -1, 0, 6], [17, -1, 12, 21, 15, 4, 3, -13, -1, -8, -8, 0, -4, -18, 6, 25, -7], [-10, -9, -3, -15, -9, 0, 3, -4, 3, 0, 2, -14, 0, 6, 0, -15, -3], [30, 0, -4, 4, 6, 4, -6, 10, 2, 0, -4, 4, -4, -2, 4, 0, 6], [-14, 11, -2, -5, -11, 7, -12, -1, 6, 7, -1, 8, 0, 9, 9, -3, 8], [-2, -4, 1, -4, -12, -9, 0, 17, -2, 3, 5, 3, 3, 13, -7, -12, 3], [-17, -5, -13, -19, -9, 2, -15, 16, 4, 9, -15, 0, 16, 17, 2, -2, 8], [0, 13, 6, 3, 7, 1, -4, -6, 3, -7, -2, 11, -2, -5, 3, 4, -2], [-10, 7, -10, -14, -9, 0, -7, 12, -1, 5, -4, -3, 9, 10, -4, 1, 8], [-4, 12, 1, 14, 4, -5, 1, -4, 3, 5, -1, 4, -2, -11, 3, 6, -3], [-7, -19, 1, -9, -1, 1, 4, -3, -1, -4, 7, -9, 6, 2, -5, -4, -7], [-28, 4, 9, -4, -6, -1, 7, -14, 1, -1, 13, 0, 2, -5, -3, -4, -9], [-17, -8, -9, -6, -2, -6, 2, 6, 5, 5, -6, 1, 8, 11, 0, 1, 5], [3, 0, 8, 0, 6, -1, 3, -10, -1, 0, -8, -12, 6, -6, -3, 2, -6], [-4, -12, -11, -2, -2, -2, 6, 6, -1, 2, 8, -7, 6, 14, -9, -3, -5], [13, -4, -4, -9, -8, 11, -7, 1, 3, -4, -4, 8, 2, 4, 5, 6, 10], [4, -14, 11, 2, -6, 3, 1, -10, 1, -3, -1, 0, 2, -1, 5, 4, 1], [6, 6, 0, -10, 0, -12, 8, 18, 0, 0, 2, -2, -10, 8, -16, -10, 6], [-13, -8, -2, -1, 2, 10, -6, -15, 1, 0, -6, 0, 3, -11, 6, 13, 0], [-1, -7, -2, -3, 5, 2, -9, -6, 1, 1, -1, 4, 0, -5, 12, 7, -2], [0, -3, 8, -15, 3, 9, -4, -1, -4, -13, -7, -8, -2, 7, -1, 9, -4], [-1, -12, -16, -13, -14, 7, -1, 0, 2, 2, 7, -3, 2, 20, -5, -17, 0], [5, 14, 0, 6, -12, 6, -18, -4, 10, 1, -8, 6, 2, -1, 13, 6, 10], [10, 6, 3, 8, 12, 7, -13, 0, 5, -1, -11, 8, 4, -15, 7, 18, -1], [1, 6, -4, -13, 2, 1, 1, 17, -1, -6, 2, 0, -6, 8, -13, 0, 6], [-8, -9, -8, -11, 1, 10, 3, -2, 9, -6, -1, -8, -2, 0, 3, -1, 4], [-16, 9, -13, -20, -8, -7, -10, 32, 2, 13, 1, -2, 2, 23, -13, -14, 10], [-10, 1, -14, 5, -3, -1, 2, 9, 0, 5, 3, 0, -2, 9, -3, -7, 8], [-9, 6, -10, -18, -6, -3, -7, 3, 1, 8, -10, 0, 8, 2, -3, 6, 8], [9, -12, 10, 8, 14, -5, 21, -3, -11, -10, 8, -2, -12, -8, -11, 2, -12], [-14, 7, 6, -12, 1, -6, 1, 21, -10, 3, 3, -2, -1, 8, -4, -8, 8], [-10, -4, -2, 0, -2, -2, 4, -4, 6, 2, 4, 0, -6, -6, 4, 2, -2], [15, 1, -3, -3, -7, -2, -3, 7, -3, 7, 2, 4, 6, 9, -3, 11, -1], [18, 8, -1, 4, -4, -7, -1, 11, -6, 1, 2, 9, -2, 3, -9, 5, 1], [4, 1, 11, 4, -4, -1, 6, 1, -5, -5, -4, 3, -4, -7, -1, 7, 6], [10, -12, 9, 5, 2, 4, -2, -13, 2, -1, -7, 0, 4, -10, 6, 6, -4], [13, -9, 1, 17, 15, 9, 12, -19, 7, -4, -3, -3, -10, -26, 9, 6, -5], [7, 6, 16, 7, -10, -18, 18, -2, -6, 6, 3, -13, -3, -1, -8, -8, -8], [2, 8, -8, -8, -4, 4, -16, 2, 2, 6, -10, 4, 8, 0, 2, 0, 12], [-4, 12, -10, -4, -4, -7, -13, 25, -7, 15, -12, 9, 10, 13, 3, 2, 11], [1, 15, -8, -11, -1, 0, -5, 16, -5, -1, -9, 4, -2, -3, 2, 1, 12], [-9, 9, -4, -5, -11, 0, 5, 0, 4, 3, 12, 1, -8, 9, -8, 0, 0], [-3, 2, -4, -2, 2, -8, 6, 15, -7, -5, 1, -3, -10, 3, -3, 1, 0], [-5, -15, 15, -2, 6, -2, 11, -10, -4, -11, 12, -11, -10, -7, -8, -7, -10], [8, 4, -4, -2, -2, -2, -2, -8, 4, 0, -4, 8, 6, 0, 6, 4, -8], [5, 16, 6, 4, 4, -3, -1, 9, -14, 0, -1, 7, 6, 0, 1, 5, -2], [-2, 5, -10, 6, 15, 6, -11, 19, 2, -5, -8, 7, -2, -2, 2, 4, 3], [1, -1, -7, 8, -1, 2, -1, -6, 4, -2, -6, -2, -5, -3, 6, -2, 7], [1, -9, 3, -7, 7, 5, 2, 0, 2, -2, 8, -6, -8, 2, -7, 1, -3], [10, 4, 1, 6, 0, 7, -3, -1, -4, -1, 10, 17, -6, 1, 11, 7, 1], [16, -8, 2, -8, 2, 4, -7, -4, 2, -4, 1, -6, 1, -2, -2, -3, 8], [-29, 3, -14, -17, -9, 2, -3, 16, 5, 3, -7, -2, -2, 13, 4, -7, 16], [20, -4, -1, -21, -4, 8, -8, 4, -1, -1, -6, -3, 6, 4, 4, 5, 8], [12, 12, 9, 17, -5, -12, 2, -7, -4, 6, 2, 6, 8, 2, 2, 5, -8], [-20, 9, -11, -7, -13, -2, -5, 3, 9, 8, -16, -2, 4, 2, 4, -9, 7], [2, -16, 4, 15, 22, 0, 2, -1, -3, -10, -7, 3, -4, -6, 2, 19, -6], [11, 1, 9, 3, 5, 9, 10, 5, 5, -10, -5, 1, -18, -8, 1, 2, 9], [-1, -8, -16, -6, 4, 7, -1, -4, -2, -6, 3, -3, 0, 0, 5, -5, -2], [5, 0, 8, -8, -6, -9, 3, 13, -6, 7, 0, -7, 2, 9, -5, -5, -5], [-1, -11, -5, -3, -5, 5, -6, 2, 0, -2, -10, 0, 4, 8, 1, 5, 3], [39, -17, 20, 7, 1, -6, 7, 8, -7, -9, 5, 2, -6, 5, -4, 1, -4], [-16, 7, 2, -3, -3, -3, 2, 0, -3, 1, 6, 3, 10, -3, -7, 8, -8], [19, -6, 10, 14, 8, 5, -1, -23, -7, -4, 0, -2, 2, -12, 3, 6, -16], [19, -10, 0, 10, 0, 7, 7, 5, -3, 0, 4, 0, 2, 0, -1, 2, -2], [-26, 19, -16, -21, -15, -6, -3, 20, 7, 12, 5, 2, 2, 24, -5, -23, 12], [1, 7, 2, -3, 9, -1, -6, 12, 3, -2, -4, 6, -6, -6, -5, 6, 1], [-18, 2, -16, 2, 10, 0, 4, 22, -4, 0, -2, 8, -2, -4, -2, -4, 4], [13, -2, 7, 26, 12, 4, 12, -13, 4, -9, 5, 4, -10, -9, 12, 0, -13], [-18, 1, -12, 6, 3, 0, -13, 3, 2, 9, -18, 7, 4, -10, 4, 10, 7], [-16, 4, -14, -8, -2, 6, -10, -1, 5, 8, -9, 3, 2, 2, 8, -11, 6], [7, -1, 7, -15, 7, 1, -6, 20, -7, -5, 4, 5, -10, -5, -3, 2, 0], [-5, -10, -1, 12, 12, -2, 6, -2, -1, -13, -8, -5, 2, 1, -8, 1, 1], [-9, -3, -5, 3, 1, -5, -2, -12, 4, 8, -8, -4, 4, -4, 3, -5, 1], [11, 7, -8, 9, 8, 10, -8, 5, -8, -3, -6, 5, -2, -11, 7, 8, -2], [-2, -4, 5, 20, 13, -3, 14, 7, -12, -1, 6, 3, -8, -5, 2, -7, -7], [0, -14, -6, 10, -6, -8, 8, -6, -4, 0, 12, -2, -2, 10, -4, -12, -6], [-3, -5, 4, 21, 6, -2, 2, -2, -7, -5, 3, 8, 2, -11, -3, 11, -4], [-24, 8, -9, -12, -20, -9, -7, 3, 10, 15, 0, -9, 2, 11, -5, -19, 7], [-16, 13, -2, 3, -17, 3, -16, -18, 11, 17, -6, 1, 16, -9, 17, 0, -2]]
